(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('rxjs'), require('@angular/animations'), require('rxjs/operators'), require('@angular/platform-browser'), require('@angular/common')) :
    typeof define === 'function' && define.amd ? define('ngx-notifier', ['exports', '@angular/core', 'rxjs', '@angular/animations', 'rxjs/operators', '@angular/platform-browser', '@angular/common'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ngx-notifier'] = {}, global.ng.core, global.rxjs, global.ng.animations, global.rxjs.operators, global.ng.platformBrowser, global.ng.common));
}(this, (function (exports, i0, rxjs, animations, operators, i2, i3) { 'use strict';

    function _interopNamespace(e) {
        if (e && e.__esModule) return e;
        var n = Object.create(null);
        if (e) {
            Object.keys(e).forEach(function (k) {
                if (k !== 'default') {
                    var d = Object.getOwnPropertyDescriptor(e, k);
                    Object.defineProperty(n, k, d.get ? d : {
                        enumerable: true,
                        get: function () {
                            return e[k];
                        }
                    });
                }
            });
        }
        n['default'] = e;
        return Object.freeze(n);
    }

    var i0__namespace = /*#__PURE__*/_interopNamespace(i0);
    var i2__namespace = /*#__PURE__*/_interopNamespace(i2);
    var i3__namespace = /*#__PURE__*/_interopNamespace(i3);

    /** Notification Class */
    var Notification = /** @class */ (function () {
        /**
         * Constructor For Notification
         *
         * @param message message to be shown
         * @param style bootstrap background colors
         * @param duration timeout for notification
         */
        function Notification(message, style, duration) {
            this.id = '_' + Math.random().toString(36).substr(2, 9); // generate a random number
            this.message = message;
            this.style = style || 'info';
            this.duration = duration;
        }
        return Notification;
    }());

    /** Notification Service, recieves notifications from user and interacts with components */
    var NgxNotifierService = /** @class */ (function () {
        function NgxNotifierService() {
            /** notification which can be subscribed on new messages */
            this.notification = new rxjs.Subject();
            /** clear all toast notifications */
            this.clearToasts = new rxjs.Subject();
            /** clear last toast notification */
            this.clearLastToast = new rxjs.Subject();
        }
        /** pushes a new notification */
        NgxNotifierService.prototype.createToast = function (message, style, duration) {
            this.notification.next(new Notification(message, style, duration));
        };
        /** clear all toast notifications */
        NgxNotifierService.prototype.clear = function () {
            this.clearToasts.next();
        };
        /** clear last toast notification */
        NgxNotifierService.prototype.clearLast = function () {
            this.clearLastToast.next();
        };
        return NgxNotifierService;
    }());
    NgxNotifierService.ɵfac = i0__namespace.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.2", ngImport: i0__namespace, type: NgxNotifierService, deps: [], target: i0__namespace.ɵɵFactoryTarget.Injectable });
    NgxNotifierService.ɵprov = i0__namespace.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.0.2", ngImport: i0__namespace, type: NgxNotifierService });
    i0__namespace.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.2", ngImport: i0__namespace, type: NgxNotifierService, decorators: [{
                type: i0.Injectable
            }] });

    /**
     * Notifier compoent, which holds all the notifications can be accessed via `ngx-notifier` selector
     */
    var NgxNotifierComponent = /** @class */ (function () {
        /**
         * NgxNotifierComponent Constructor
         *
         * @param ngxNotifierService subscribe to get values form notifier service
         */
        function NgxNotifierComponent(ngxNotifierService, domSanitizer) {
            var _this = this;
            this.ngxNotifierService = ngxNotifierService;
            this.domSanitizer = domSanitizer;
            this.componentDestroyed$ = new rxjs.Subject();
            /** whether to allow duplicate messages or not */
            this.allowDuplicates = true;
            /** allow HTML in notification */
            this.allowHTML = false;
            /** custom class to be attached */
            this.className = '';
            /** default duration for dismissing notifications (60s/1minute) */
            this.duration = 60000;
            /** weather to enable or disable animations */
            this.disableAnimations = false;
            /** click to dismiss a notification */
            this.dismissOnClick = false;
            /** whether to insert on top or at bottom */
            this.insertOnTop = true;
            /** Maximum number of notifications to keep */
            this.max = 5;
            /** array of notifications */
            this.notifications = [];
            this.ngxNotifierService.notification.pipe(operators.takeUntil(this.componentDestroyed$)).subscribe(function (notification) { _this.updateNotifications(notification); });
            this.ngxNotifierService.clearToasts.pipe(operators.takeUntil(this.componentDestroyed$)).subscribe(function () { _this.notifications = []; });
            this.ngxNotifierService.clearLastToast.pipe(operators.takeUntil(this.componentDestroyed$)).subscribe(function () { _this.clearLastToast(); });
        }
        /**
         * updates notification into the array i.e., Which is the display
         *
         * @param notification notification element
         */
        NgxNotifierComponent.prototype.updateNotifications = function (notification) {
            var _this = this;
            // checks whether the message is alrady present in notifications
            var index = this.notifications.map(function (e) { return e.message; }).indexOf(notification.message);
            if (!this.allowDuplicates) {
                if (index !== -1) {
                    return;
                }
            }
            // save the last inserted Id
            this.lastInsertedNotificationId = notification.id;
            // sanitize html if enableHTML is set to true
            var sanitizedMessage = null;
            if (notification.message && this.allowHTML) {
                sanitizedMessage = this.domSanitizer.sanitize(i0.SecurityContext.HTML, notification.message);
            }
            // set sanitized output to notification message
            notification.message = sanitizedMessage || notification.message;
            // insert notification in the first position of the array
            if (this.insertOnTop) {
                this.notifications.unshift(notification);
            }
            else {
                this.notifications.push(notification);
            }
            /**
             * remove the last inserted element if max has
             * pop or shift based on `insertOnTop`
             */
            if (this.notifications.length > this.max) {
                if (this.insertOnTop) {
                    this.notifications.pop();
                }
                else {
                    this.notifications.shift();
                }
            }
            // clear notification in given time
            setTimeout(function () {
                _this.notifications.splice(index, 1);
            }, notification.duration || this.duration);
            return;
        };
        /**
         * remove the element from the array based on index
         *
         * @param index position of the element
         */
        NgxNotifierComponent.prototype.removeNotification = function (index) {
            if (index !== undefined || index !== null) {
                this.notifications.splice(index, 1);
            }
            return;
        };
        /**
         * click event when toast is cleared
         *
         * @param index position of the element
         */
        NgxNotifierComponent.prototype.onToastClick = function (index) {
            if (this.dismissOnClick) {
                this.removeNotification(index);
            }
            return;
        };
        /** clear last inserted toast notification */
        NgxNotifierComponent.prototype.clearLastToast = function () {
            var index = this.notifications.map(function (e) { return e.id; }).indexOf(this.lastInsertedNotificationId);
            if (this.notifications.length !== 0 && index !== -1) {
                this.notifications.splice(index, 1);
            }
            return;
        };
        /** stop subscription when component is destroyed */
        NgxNotifierComponent.prototype.ngOnDestroy = function () {
            this.componentDestroyed$.next();
            this.componentDestroyed$.complete();
        };
        return NgxNotifierComponent;
    }());
    NgxNotifierComponent.ɵfac = i0__namespace.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.2", ngImport: i0__namespace, type: NgxNotifierComponent, deps: [{ token: NgxNotifierService }, { token: i2__namespace.DomSanitizer }], target: i0__namespace.ɵɵFactoryTarget.Component });
    NgxNotifierComponent.ɵcmp = i0__namespace.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.0.2", type: NgxNotifierComponent, selector: "ngx-notifier", inputs: { allowDuplicates: "allowDuplicates", allowHTML: "allowHTML", className: "className", duration: "duration", disableAnimations: "disableAnimations", dismissOnClick: "dismissOnClick", insertOnTop: "insertOnTop", max: "max" }, ngImport: i0__namespace, template: "<div class=\"ngx-notifier\" *ngIf=\"notifications?.length !== 0\" [ngClass]=\"className\" [@animateToasts]\n  [@.disabled]=\"disableAnimations\">\n  <div [ngClass]=\"{'pointer': dismissOnClick}\">\n    <div class=\"ngx-n-notification alert\" role=\"alert\" *ngFor=\"let notification of notifications; let i = index\"\n      [ngClass]=\"'alert-'+ notification.style\" (click)=\"onToastClick(i)\" [@animateToasts]>\n      <button type=\"button\" class=\"pointer close\" aria-label=\"Close\" (click)=\"removeNotification(i)\">\n        <svg xmlns=\"http://www.w3.org/2000/svg\" width=\"12\" height=\"12\" fill=\"currentColor\" viewBox=\"0 0 16 16\"\n          aria-hidden=\"true\">\n          <path\n            d=\"M1.293 1.293a1 1 0 0 1 1.414 0L8 6.586l5.293-5.293a1 1 0 1 1 1.414 1.414L9.414 8l5.293 5.293a1 1 0 0 1-1.414 1.414L8 9.414l-5.293 5.293a1 1 0 0 1-1.414-1.414L6.586 8 1.293 2.707a1 1 0 0 1 0-1.414z\" />\n        </svg>\n      </button>\n      <p *ngIf=\"allowHTML\" [innerHTML]=\"notification.message\"> </p>\n      <p *ngIf=\"!allowHTML\">{{ notification.message }} </p>\n    </div>\n  </div>\n</div>\n", styles: ["*,:after,:before{box-sizing:border-box}.ngx-notifier{position:fixed;min-width:25rem;max-width:25rem;right:1rem;bottom:1rem}.ngx-notifier .pointer{cursor:pointer}.ngx-notifier .ngx-n-notification{margin-top:.5rem;border-radius:4px;padding:.5rem}.ngx-notifier .ngx-n-notification p{margin:0}.ngx-notifier .ngx-n-notification .close:focus{outline:none}.ngx-notifier .alert{position:relative;padding:1rem 3rem 1rem 1rem;margin-bottom:1rem;border:1px solid transparent;border-radius:.25rem}.ngx-notifier .alert-success{color:#0f5132;background-color:#d1e7dd;border-color:#badbcc}.ngx-notifier .alert-info{color:#055160;background-color:#cff4fc;border-color:#b6effb}.ngx-notifier .alert-warning{color:#664d03;background-color:#fff3cd;border-color:#ffecb5}.ngx-notifier .alert-danger{color:#842029;background-color:#f8d7da;border-color:#f5c2c7}.ngx-notifier .close{position:absolute;top:0;right:0;z-index:2;padding:1.25rem 1rem;width:1rem;height:1rem;background-color:transparent;border:none;box-sizing:content-box}@media only screen and (max-width:420px){.ngx-notifier{min-width:20rem;max-width:20rem}}"], directives: [{ type: i3__namespace.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i3__namespace.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i3__namespace.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }], animations: [
            animations.trigger('animateToasts', [
                animations.state('void', animations.style({ opacity: 0 })),
                animations.transition(':enter, :leave', [
                    animations.animate('0.3s ease')
                ])
            ])
        ] });
    i0__namespace.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.2", ngImport: i0__namespace, type: NgxNotifierComponent, decorators: [{
                type: i0.Component,
                args: [{
                        selector: 'ngx-notifier',
                        templateUrl: './ngx-notifier.component.html',
                        styleUrls: ['./ngx-notifier.component.scss'],
                        animations: [
                            animations.trigger('animateToasts', [
                                animations.state('void', animations.style({ opacity: 0 })),
                                animations.transition(':enter, :leave', [
                                    animations.animate('0.3s ease')
                                ])
                            ])
                        ]
                    }]
            }], ctorParameters: function () { return [{ type: NgxNotifierService }, { type: i2__namespace.DomSanitizer }]; }, propDecorators: { allowDuplicates: [{
                    type: i0.Input
                }], allowHTML: [{
                    type: i0.Input
                }], className: [{
                    type: i0.Input
                }], duration: [{
                    type: i0.Input
                }], disableAnimations: [{
                    type: i0.Input
                }], dismissOnClick: [{
                    type: i0.Input
                }], insertOnTop: [{
                    type: i0.Input
                }], max: [{
                    type: i0.Input
                }] } });

    var NgxNotifierModule = /** @class */ (function () {
        function NgxNotifierModule() {
        }
        return NgxNotifierModule;
    }());
    NgxNotifierModule.ɵfac = i0__namespace.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.0.2", ngImport: i0__namespace, type: NgxNotifierModule, deps: [], target: i0__namespace.ɵɵFactoryTarget.NgModule });
    NgxNotifierModule.ɵmod = i0__namespace.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.0.2", ngImport: i0__namespace, type: NgxNotifierModule, declarations: [NgxNotifierComponent], imports: [i3.CommonModule], exports: [NgxNotifierComponent] });
    NgxNotifierModule.ɵinj = i0__namespace.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.0.2", ngImport: i0__namespace, type: NgxNotifierModule, providers: [NgxNotifierService], imports: [[i3.CommonModule]] });
    i0__namespace.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.0.2", ngImport: i0__namespace, type: NgxNotifierModule, decorators: [{
                type: i0.NgModule,
                args: [{
                        imports: [i3.CommonModule],
                        declarations: [NgxNotifierComponent],
                        providers: [NgxNotifierService],
                        exports: [NgxNotifierComponent]
                    }]
            }] });

    /*
     * Public API Surface of ngx-notifier
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.NgxNotifierComponent = NgxNotifierComponent;
    exports.NgxNotifierModule = NgxNotifierModule;
    exports.NgxNotifierService = NgxNotifierService;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-notifier.umd.js.map
